==> pot-3.3.1.src.tar.gz: pot-3.3/potgtk.c <==
/*
  PotGtk V0.0.1
  _GruiCkyfied_ bY Tah0rG 
  
  tuesday April 22 2001 PM 10h12 - AM 00h56
  Gcu-squad DTC compliant

  retoucher par Pinotgui et Fabs (TaHorg : ARRETE DE FUMER !!!)
*/

#ifdef GTKUSE

#include "potgtk.h"
#include <string.h>
#include "commun.h"
#include <unistd.h>

/*variable de selection de la c-liste*/
gint mySELECTED_ROW=0;

#ifdef AUTOKILL
pid_t father; /* pid du pere */
#endif

int potgtk(char *chemin, int argc, char *argv[])
{
  GtkWidget *window; /* la fenetre principale*/
  GtkWidget *button[3]; /*dans l'ordre refresh, talk, quit*/
  GtkWidget *menu; /* menu option */
  GtkWidget *menu_bar; /* barre de menu */
  GtkWidget *item[3]; /* ?? */
  GtkWidget *box[2]; /* ?? */
  GtkWidget *liste; /*la liste qui contient les "Pots"*/
  GtkWidget *label; /*le lable de titre*/ 
  struct commune *passing; /* Structure ToP-BiDoUilLe pour pouvoir passer tout ce qui faut  rafraichi */
  gchar *titre[4]={"Login","Talk","Nom","Salle"};
  gint i;
  
  gtk_init (&argc, &argv);

#ifdef AUTOKILL
  father = getppid( );
#endif
  
  /**window**/
  window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_widget_set_usize(GTK_WIDGET(window),400,300);
  gtk_window_set_title (GTK_WINDOW (window), "PotGTK");
  
  gtk_signal_connect (GTK_OBJECT (window), "delete_event",
                        GTK_SIGNAL_FUNC (quit_pot), NULL);
  
  gtk_container_border_width (GTK_CONTAINER (window), 10);
  /************/
  
  box[0] = gtk_vbox_new(FALSE, 5); /*boite generale*/
  box[1] = gtk_hbox_new(TRUE, 0); /*boite qui contient les boutons*/
  
  /**menu**/
  
  menu_bar = gtk_menu_bar_new();
  gtk_box_pack_start(GTK_BOX(box[0]), menu_bar, FALSE, TRUE, 0);
  menu=gtk_menu_new();
  item[0]=gtk_menu_item_new_with_label("Options");
  item[1]=gtk_menu_item_new_with_label("Gerer ses pots");
  item[2]=gtk_menu_item_new_with_label("Quitte");
  
  gtk_signal_connect (GTK_OBJECT (item[2]), "activate",
		      GTK_SIGNAL_FUNC (quit_pot), NULL);
  gtk_signal_connect (GTK_OBJECT (item[1]), "activate",
		      GTK_SIGNAL_FUNC (gestion), NULL);
 
  for(i=1;i<3;i++)
    {
      gtk_menu_append( GTK_MENU(menu), item[i]);
      gtk_widget_show(item[i]);
    }

  gtk_menu_bar_append( GTK_MENU_BAR (menu_bar), item[0]);
  gtk_menu_item_set_submenu(GTK_MENU_ITEM (item[0]), menu);
  gtk_widget_show(item[0]);
  gtk_widget_show(menu_bar);
  /********/

  
  /**label**/
  label=gtk_label_new("Pot C toP");
  gtk_box_pack_start(GTK_BOX(box[0]), label, FALSE, TRUE, 0);
  /************/
 
  
  /**clist**/
  liste=gtk_clist_new_with_titles(4,titre);
  gtk_clist_set_column_width (GTK_CLIST(liste), 0, 80);
  gtk_clist_set_column_width (GTK_CLIST(liste), 1, 30);
  gtk_clist_set_column_width (GTK_CLIST(liste), 2, 120);
 

  gtk_signal_connect(GTK_OBJECT(liste),
		     "select_row",
		     GTK_SIGNAL_FUNC(save_selected),
		     NULL);

  gtk_box_pack_start(GTK_BOX(box[0]), liste, TRUE, TRUE, 0);
  /************/
  
    
  /*buttons*/
  button[0] = gtk_button_new_with_label ("REfreSh");
  gtk_signal_connect (GTK_OBJECT (button[0]), "clicked",
		      GTK_SIGNAL_FUNC (refresh_list), (gpointer) liste);
    
  button[1] = gtk_button_new_with_label ("TaLk");
  gtk_signal_connect (GTK_OBJECT (button[1]), "clicked",
		      GTK_SIGNAL_FUNC (talk_selected), (gpointer) liste);
    
  button[2] = gtk_button_new_with_label ("Quit");
  gtk_signal_connect (GTK_OBJECT (button[2]), "clicked",
		      GTK_SIGNAL_FUNC (quit_pot), NULL);
    
  for(i=0;i<3;i++)
    gtk_box_pack_start(GTK_BOX(box[1]), button[i], FALSE, TRUE, 10);
  /************/
    
  gtk_box_pack_start(GTK_BOX(box[0]), box[1], FALSE, TRUE, 0);
  gtk_container_add (GTK_CONTAINER (window), box[0]);  
  
  gtk_widget_show(liste);
  gtk_widget_show(label);
 
  for(i=0;i<2;i++)
    gtk_widget_show(box[i]);
  
  for(i=0;i<3;i++)
    gtk_widget_show(button[i]);

  gtk_widget_show (window);
  
  refresh_list (button[0], (gpointer) liste);
  /* On rafraichi priodiquement */
  if ( (passing = (struct commune *)malloc(sizeof(struct commune))) == NULL )
    {
      fprintf ( stderr , "Allocation de memoire impossible\n" );
      return -1;
    }
  passing->widget = button[0];
  passing->liste = liste;
  gtk_timeout_add( (guint32) TEMPS_MAX ,
		   (GtkFunction)passe, (gpointer) passing );
  
  gtk_main ();
  
  return 0;

}


void refresh_list (GtkWidget *widget, gpointer data)
{
  gchar **text;
  char *chemin;
  int i;
  int compteur;
  
  if ( ( chemin = (char *) malloc(sizeof(char)*(strlen(getenv("HOME")) + 20)) ) == NULL )
    {
      fprintf( stderr , "Allocation de memoire impossible" );
      return ;
    }
  strcpy ( chemin , getenv("HOME") );
  strcat ( chemin , "/.pot.pot" );
  
  gtk_clist_clear (GTK_CLIST(data));
    

  if ( ( text = (gchar **)calloc(5, sizeof(gchar *)) ) == NULL )
    {
      fprintf ( stderr , "Allocation de memoire impossible\n" );
      return;
    }

  compteur = recherche_pots(chemin);

  connecte = &depart;
  
  while ( (connecte = connecte->next) )
    { 
      i = 0;
      text[i] = connecte->login;
      i++;
      if ( connecte->talk == 2)
	{
	  if ( ( text[i] = strdup("w") ) == NULL )
	    {
	      fprintf(stderr,
		      "Probleme avec strdup : %s  la ligne %d dans le fichier %s\n",
		      strerror(errno) , __LINE__ , __FILE__);
	      return;
	    }
	}
      else if ( connecte->talk == 1)
	{
	  if ( ( text[i] = strdup("+") ) == NULL )
	    {
	      fprintf(stderr,
		      "Probleme avec strdup : %s  la ligne %d dans le fichier %s\n",
		      strerror(errno) , __LINE__ , __FILE__);
	      return;
	    }
	}
      else
	if ( ( text[i] = strdup("-") ) == NULL )
	  {
	    fprintf(stderr,
		    "Probleme avec strdup : %s  la ligne %d dans le fichier %s\n",
		    strerror(errno) , __LINE__ , __FILE__);
	    return;
	  }
      
      i++;
      text[i] = connecte->nom;
      i++;
      text[i] = connecte->salle;
      i++;
	 gtk_clist_insert (GTK_CLIST(data),0,text);
    }


  free(chemin);
  free_liste();
  free(text);

  gtk_widget_show(widget);

  return;
}

void quit_pot (GtkWidget *widget, gpointer data)
{
  gtk_main_quit ();
  return;
}


void talk_selected(GtkWidget *widget,
		   gpointer data)
{
  gchar *text[9];
  gchar *talk[3];
  gchar argv[60];

  
  gtk_clist_get_text( GTK_CLIST(data),mySELECTED_ROW,0,(gchar **)text);
  gtk_clist_get_text( GTK_CLIST(data),mySELECTED_ROW,1,(gchar **)talk);
  if (*talk[0]=='+')
    {
      sprintf(argv,"%s -e talk %s &", XTERM, text[0]);
      system(argv);
    }

}

void save_selected(GtkWidget *widget,
		   gint row,
		   gint column,
		   GdkEventButton *event,
		   gpointer data)
{
  mySELECTED_ROW=row;
}

/* Fonction ToP-BiDoUilLe pour pouvoir passer  rafraichi les bons arguments */
gboolean passe( struct commune *data )
{
#ifdef AUTOKILL
  if ( father != getppid( ) )
    quit_pot((GtkWidget *)data->widget, (gpointer)data->liste);
#endif

  refresh_list((GtkWidget *)data->widget, (gpointer)data->liste);
  return TRUE;
}

#endif

==> pot-3.3.2.src.tar.gz: pot-3.3/potgtk.c <==
/*
  PotGtk V0.0.1
  _GruiCkyfied_ bY Tah0rG 
  
  tuesday April 22 2001 PM 10h12 - AM 00h56
  Gcu-squad DTC compliant

  retoucher par Pinotgui et Fabs (TaHorg : ARRETE DE FUMER !!!)
*/

#ifdef GTKUSE

#include <string.h>
#include <unistd.h>
#include "commun.h"
#include "potgtk.h"

/*variable de selection de la c-liste*/
gint mySELECTED_ROW=0;

#ifdef AUTOKILL
pid_t father; /* pid du pere */
#endif

int potgtk(char *chemin, int argc, char *argv[])
{
  GtkWidget *window; /* la fenetre principale*/
  GtkWidget *button[3]; /*dans l'ordre refresh, talk, quit*/
  GtkWidget *menu; /* menu option */
  GtkWidget *menu_bar; /* barre de menu */
  GtkWidget *item[3]; /* ?? */
  GtkWidget *box[2]; /* ?? */
  GtkWidget *liste; /*la liste qui contient les "Pots"*/
  GtkWidget *label; /*le lable de titre*/ 
  struct commune *passing; /* Structure ToP-BiDoUilLe pour pouvoir passer tout ce qui faut  rafraichi */
  gchar *titre[5]={"Login","Talk","Idle","Nom","Salle"};
  gint i;
  
  gtk_init (&argc, &argv);

#ifdef AUTOKILL
  father = getppid( );
#endif
  
  /**window**/
  window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_widget_set_usize(GTK_WIDGET(window),460,350);
  gtk_window_set_title (GTK_WINDOW (window), "PotGTK");
  
  gtk_signal_connect (GTK_OBJECT (window), "delete_event",
                        GTK_SIGNAL_FUNC (quit_pot), NULL);
  
  gtk_container_border_width (GTK_CONTAINER (window), 10);
  /************/
  
  box[0] = gtk_vbox_new(FALSE, 5); /*boite generale*/
  box[1] = gtk_hbox_new(TRUE, 0); /*boite qui contient les boutons*/
  
  /**menu**/
  
  menu_bar = gtk_menu_bar_new();
  gtk_box_pack_start(GTK_BOX(box[0]), menu_bar, FALSE, TRUE, 0);
  menu=gtk_menu_new();
  item[0]=gtk_menu_item_new_with_label("Options");
  item[1]=gtk_menu_item_new_with_label("Gerer ses pots");
  item[2]=gtk_menu_item_new_with_label("Quitte");
  
  gtk_signal_connect (GTK_OBJECT (item[2]), "activate",
		      GTK_SIGNAL_FUNC (quit_pot), NULL);
  gtk_signal_connect (GTK_OBJECT (item[1]), "activate",
		      GTK_SIGNAL_FUNC (gestion), NULL);
 
  for(i=1;i<3;i++)
    {
      gtk_menu_append( GTK_MENU(menu), item[i]);
      gtk_widget_show(item[i]);
    }

  gtk_menu_bar_append( GTK_MENU_BAR (menu_bar), item[0]);
  gtk_menu_item_set_submenu(GTK_MENU_ITEM (item[0]), menu);
  gtk_widget_show(item[0]);
  gtk_widget_show(menu_bar);
  /********/

  
  /**label**/
  label=gtk_label_new("Pot C toP");
  gtk_box_pack_start(GTK_BOX(box[0]), label, FALSE, TRUE, 0);
  /************/
 
  
  /**clist**/
  liste=gtk_clist_new_with_titles(5,titre);
  gtk_clist_set_column_width (GTK_CLIST(liste), 0, 80);
  gtk_clist_set_column_width (GTK_CLIST(liste), 1, 30);
  gtk_clist_set_column_width (GTK_CLIST(liste), 2, 40);
  gtk_clist_set_column_width (GTK_CLIST(liste), 3, 120);
 

  gtk_signal_connect(GTK_OBJECT(liste),
		     "select_row",
		     GTK_SIGNAL_FUNC(save_selected),
		     NULL);

  gtk_box_pack_start(GTK_BOX(box[0]), liste, TRUE, TRUE, 0);
  /************/
  
    
  /*buttons*/
  button[0] = gtk_button_new_with_label ("REfreSh");
  gtk_signal_connect (GTK_OBJECT (button[0]), "clicked",
		      GTK_SIGNAL_FUNC (refresh_list), (gpointer) liste);
    
  button[1] = gtk_button_new_with_label ("TaLk");
  gtk_signal_connect (GTK_OBJECT (button[1]), "clicked",
		      GTK_SIGNAL_FUNC (talk_selected), (gpointer) liste);
    
  button[2] = gtk_button_new_with_label ("Quit");
  gtk_signal_connect (GTK_OBJECT (button[2]), "clicked",
		      GTK_SIGNAL_FUNC (quit_pot), NULL);
    
  for(i=0;i<3;i++)
    gtk_box_pack_start(GTK_BOX(box[1]), button[i], FALSE, TRUE, 10);
  /************/
    
  gtk_box_pack_start(GTK_BOX(box[0]), box[1], FALSE, TRUE, 0);
  gtk_container_add (GTK_CONTAINER (window), box[0]);  
  
  gtk_widget_show(liste);
  gtk_widget_show(label);
 
  for(i=0;i<2;i++)
    gtk_widget_show(box[i]);
  
  for(i=0;i<3;i++)
    gtk_widget_show(button[i]);

  gtk_widget_show (window);
  
  refresh_list (button[0], (gpointer) liste);
  /* On rafraichi priodiquement */
  if ( (passing = (struct commune *)malloc(sizeof(struct commune))) == NULL )
    {
      fprintf ( stderr , "Allocation de memoire impossible\n" );
      return -1;
    }
  passing->widget = button[0];
  passing->liste = liste;
  gtk_timeout_add( (guint32) TEMPS_MAX ,
		   (GtkFunction)passe, (gpointer) passing );
  
  gtk_main ();
  
  return 0;

}


void refresh_list (GtkWidget *widget, gpointer data)
{
  gchar **text;
  char *chemin;
  int i;
  int compteur;
  
  if ( ( chemin = (char *) malloc(sizeof(char)*(strlen(getenv("HOME")) + 20)) ) == NULL )
    {
      fprintf( stderr , "Allocation de memoire impossible" );
      return ;
    }
  strcpy ( chemin , getenv("HOME") );
  strcat ( chemin , "/.pot.pot" );
  
  gtk_clist_clear (GTK_CLIST(data));
    

  if ( ( text = (gchar **)calloc(5, sizeof(gchar *)) ) == NULL )
    {
      fprintf ( stderr , "Allocation de memoire impossible\n" );
      return;
    }

  compteur = recherche_pots(chemin);

  connecte = &depart;
  
  while ( (connecte = connecte->next) )
    { 
      i = 0;
      text[i] = connecte->login;
      i++;
      if ( connecte->talk == 2)
	{
	  if ( ( text[i] = strdup("w") ) == NULL )
	    {
	      fprintf(stderr,
		      "Probleme avec strdup : %s  la ligne %d dans le fichier %s\n",
		      strerror(errno) , __LINE__ , __FILE__);
	      return;
	    }
	}
      else if ( connecte->talk == 1)
	{
	  if ( ( text[i] = strdup("+") ) == NULL )
	    {
	      fprintf(stderr,
		      "Probleme avec strdup : %s  la ligne %d dans le fichier %s\n",
		      strerror(errno) , __LINE__ , __FILE__);
	      return;
	    }
	}
      else
	if ( ( text[i] = strdup("-") ) == NULL )
	  {
	    fprintf(stderr,
		    "Probleme avec strdup : %s  la ligne %d dans le fichier %s\n",
		    strerror(errno) , __LINE__ , __FILE__);
	    return;
	  }
      
      i++;
      text[i] = (gchar *) print_idle(connecte->idle);
      i++;
      text[i] = connecte->nom;
      i++;
      text[i] = connecte->salle;
      i++;
	 gtk_clist_insert (GTK_CLIST(data),0,text);
    }


  free(chemin);
  free_liste();
  free(text);

  gtk_widget_show(widget);

  return;
}

void quit_pot (GtkWidget *widget, gpointer data)
{
  gtk_main_quit ();
  return;
}


void talk_selected(GtkWidget *widget,
		   gpointer data)
{
  gchar *text[9];
  gchar *talk[3];
  gchar argv[60];

  
  gtk_clist_get_text( GTK_CLIST(data),mySELECTED_ROW,0,(gchar **)text);
  gtk_clist_get_text( GTK_CLIST(data),mySELECTED_ROW,1,(gchar **)talk);
  if (*talk[0]=='+')
    {
      sprintf(argv,"%s -e talk %s &", XTERM, text[0]);
      system(argv);
    }

}

void save_selected(GtkWidget *widget,
		   gint row,
		   gint column,
		   GdkEventButton *event,
		   gpointer data)
{
  mySELECTED_ROW=row;
}

/* Fonction ToP-BiDoUilLe pour pouvoir passer  rafraichi les bons arguments */
gboolean passe( struct commune *data )
{
#ifdef AUTOKILL
  if ( father != getppid( ) )
    quit_pot((GtkWidget *)data->widget, (gpointer)data->liste);
#endif

  refresh_list((GtkWidget *)data->widget, (gpointer)data->liste);
  return TRUE;
}

#endif
